import Taro from "@tarojs/taro";
import {
  View,
  Button,
  CheckboxGroup,
  Label,
  Checkbox,
} from "@tarojs/components";
import { API_GET_AGENT_BUILDINGS, API_ITEMS_LIST } from "@/constants/api";
import { ROLE_CODE } from "@/constants/user";
import { useSelector } from "react-redux";
import { fetch } from "@/utils/request";

import { useState, useEffect, useMemo } from "react";
import "./style.css";

const wrapAnimate = "wrap wrapAnimate";
const frameAnimate = "frame-wrapper";

export default (props) => {
  const { value, onChange, role } = props;

  const city = useSelector((state) => state.city);
  console.log(value, "==288888=");
  const [dicts, setDicts] = useState([]);
  const [visible, setVisible] = useState(false);
  const [loading, setLoading] = useState(false);
  // const [val, setVal] = useState({ buildingName: '意向楼盘' })
  // const [buildingTitle, setBuildingTitle] = useState({ buildingName: '意向楼盘' })
  const [buildingList, setBuildingList] = useState([]);

  const buildingProp = useMemo(
    () =>
      (dicts || []).filter((x) => value?.find((y) => y === x.buildingId)) || [],
    [value, dicts]
  );
  console.log(buildingProp, value, "buildingProp");
  useEffect(() => {
    setBuildingList(buildingProp);
  }, [buildingProp]);

  useEffect(() => {
    setLoading(true);

    if (
      role !== ROLE_CODE.CUSTOMER &&
      role !== ROLE_CODE.DRIFT &&
      role !== ROLE_CODE.CONSULTANT &&
      role !== ROLE_CODE.BROKER
    ) {
      fetch({ url: API_GET_AGENT_BUILDINGS })
        .then((res) => {
          setDicts(res || []);
          setLoading(false);
        })
        .catch(() => setLoading(false));
    } else {
      fetch({
        url: API_ITEMS_LIST,
        payload: {
          pageNumber: 1,
          pageSize: 1000,
          cityId: city.curCity.id,
          isBroker: role === ROLE_CODE.BROKER,
        },
      })
        .then((res) => {
          setDicts(res.records);
          setLoading(false);
        })
        .catch(() => setLoading(false));
    }
  }, [city.curCity.id, role]);

  const handleSelect = (e) => {
    console.log(e.detail.value);
    // const buildingId = e.detail.value;
    const building = dicts.filter((x) =>
      e.detail.value?.find((y) => y === x.buildingId)
    );

    setBuildingList(building);
  };
  const handleSubmit = (e) => {
    e.stopPropagation();
    setVisible(false);

    onChange(
      buildingList.map((x) => x.buildingId),
      buildingList
    );
  };

  const handleCancel = () => {
    setVisible(false);
    setBuildingList((dicts || []).filter((x) => value?.find((y) => y === x.buildingId)) || []);
    
  };

  return (
    <view>
      {visible ? (
        <>
          <view onClick={handleCancel} className={wrapAnimate}></view>
          <view className={frameAnimate} catchMove>
            <view className="frame">
              {/* 标题  */}
              <view className="title-wrapper">
                <view>请选择</view>
              </view>
              {/* 内容 */}
              <view style="overflow-x: hidden;">
                <View className="page-section">
                  <View className="radio-list">
                    <scroll-view
                      scrollY
                      style={{ height: "40vh", overflow: "hidden" }}
                      catchMove
                    >
                      {loading && "加载中..."}
                      {!loading && (
                        <CheckboxGroup
                          className="radio-list__RadioGroup"
                          onChange={handleSelect}
                          onClick={(e) => e.stopPropagation()}
                        >
                          {dicts.map((item, i) => {
                            return (
                              <Label
                                catchMove
                                className="radio-list__label"
                                for={`rdo-${i}`}
                                key={i}
                              >
                                <view className="radio-list__text">
                                  {item.buildingName}
                                </view>

                                <Checkbox
                                  id={`rdo-${i}`}
                                  catchMove
                                  className="radio-list__radio"
                                  value={item.buildingId}
                                  checked={
                                    !!buildingList.find((x) => item === x)
                                  }
                                ></Checkbox>
                              </Label>
                            );
                          })}
                        </CheckboxGroup>
                      )}
                    </scroll-view>
                  </View>
                </View>

                {/* <view className='bottom-text' onClick={handleTextNext}> */}
                <view style={{ display: "flex", margin: "2em auto" }}>
                  <Button className="checkBtn" onClick={handleCancel}>
                    取消
                  </Button>
                  <Button
                    className="okBtn"
                    // disabled={!current.buildingId}
                    onClick={handleSubmit}
                  >
                    
                    确定
                  </Button>
                </view>
                {/* <view className='Btn'>
                    <Button onClick={handleCancel} >取消</Button>
                    <Button disabled={!val.buildingId} onClick={handleSubmit}>确定</Button>
                  </view> */}
              </view>
            </view>
          </view>
        </>
      ) : (
        <View onClick={() => setVisible(true)}>
          {buildingList?.length>0? buildingList?.map((x,index) => index===0? x.buildingName:`、${x.buildingName}`) : "请选择"}
        </View>
      )}
    </view>
  );
};
