import { useState, useEffect } from 'react'
import withLayout from '@/layout'
import '@/assets/css/iconfont.css'
import { ScrollView } from '@tarojs/components'
import { fetch } from '@/utils/request'
import { API_SEX_INFO, API_ECHERTS_DAILY, API_ECHERTS_MONTH } from '@/constants/api'
import LineChart from './components/LineChart'
// import dayjs from 'dayjs'
import './index.scss'

const round100 = x => Number(x * 100).toFixed(2);

export default withLayout((props) => {
  const { person } = props
  const PersonId = person.personId

  const [MenuList] = useState([
    { name: '新增客户', id: 1 },
    { name: '跟进客户', id: 2 },
    { name: '到访客户', id: 3 }
  ])
  const [CurrentMenuId, setCurrentMenuId] = useState(1)

  const [ChartMenuList] = useState([
    { name: '日', id: 1 },
    { name: '月', id: 2 }
  ])
  const [CurrentChartMenuId, setCurrentChartMenuId] = useState(1)

  const [SexList, setSexList] = useState([])

  const [dimensions, setDimensions] = useState(['day', 'customerNum'])
  const [source, setSource] = useState([])

  useEffect(() => {
    if (CurrentChartMenuId && CurrentMenuId) {
      GetSexInfo()
      GetChartInfo()
    }
  }, [CurrentChartMenuId, CurrentMenuId])

  const GetSexInfo = () => {
    fetch({ url: `${API_SEX_INFO}/${CurrentMenuId === 1 ? 'new' : CurrentMenuId === 2 ? 'follow' : 'visite'}`, method: 'get' }).then((res) => {
      const SexRes = (res || []).map((item) => {
        return { name: item.genderType == 1 ? '男' : item.genderType == 2 ? '女' : '未知', per: item.percentage }
      })
      setSexList(SexRes.length ? SexRes : [
        { name: '男', per: 0 },
        { name: '女', per: 0 },
        { name: '未知', per: 0 }
      ])
    })
  }

  const GetChartInfo = () => {
    const url = `${CurrentChartMenuId === 1 ? API_ECHERTS_DAILY : API_ECHERTS_MONTH}/${CurrentMenuId === 1 ? 'new' : CurrentMenuId === 2 ? 'follow' : 'visite'}`
    fetch({ url, method: 'get' }).then((res) => {
      const Arr = (res || []).reverse()
      setSource(Arr)
    })
  }

  const CutMenu = (item) => {
    return () => {
      setCurrentMenuId(item.id)
    }
  }

  const CutChartMenu = (item) => {
    return () => {
      setCurrentChartMenuId(item.id)
      if (item.id === 1) {
        setDimensions(['day', 'customerNum'])
      } else {
        setDimensions(['month', 'customerNum'])
      }
    }
  }

  return (
    <view className='Page customerAnalyse flex-v'>

      <view className='MenuList'>
        <view>
          {
            MenuList.map((item, index) => (
              <text key={`MenuItem-${index}`} className={CurrentMenuId === item.id ? 'active' : ''} onClick={CutMenu(item)}>{item.name}</text>
            ))
          }
        </view>
      </view>

      <view className='flex-item'>
        <view>
          <ScrollView scroll-y refresher-enabled={false}>
            <view className='PageContent'>

              {/* 图表 */}
              <view className='Chart'>
                <view className='Menu'>
                  {
                    ChartMenuList.map((item, index) => (
                      <text key={`ChartMenuItem-${index}`} className={CurrentChartMenuId === item.id ? 'active' : ''} onClick={CutChartMenu(item)}>{item.name}</text>
                    ))
                  }
                </view>
                <view className='LineChart'>
                  <LineChart dimensions={dimensions} source={source} />
                </view>
              </view>

              {/* 性别 */}
              <view className='Sex'>
                <text>性别</text>
                {
                  SexList.map((item, index) => (
                    <view className='flex-h' key={`SexItem-${index}`}>
                      <text>{item.name}</text>
                      <view className='flex-item'>
                        <view style={{ width: `${round100(item.per)}%` }}></view>
                      </view>
                      <text>{round100(item.per)}%</text>
                    </view>
                  ))
                }
              </view>

            </view>
          </ScrollView>
        </view>
      </view>

    </view>
  )
})
