import { useState, useEffect } from "react";
import withLayout from "@/layout";
import { ScrollView, Input, Image, Block, Picker } from "@tarojs/components";
import "@/assets/css/iconfont.css";
import { getCardList, getAgents } from "@/services/card";
import { fetch } from "@/utils/request";
import Taro from "@tarojs/taro";
import { formatDate } from "@/utils/chatDate";
import {
  API_SURE_CHIP,
  API_BUILDING_HOUSE_TYPE,
  API_SURE_SIGN,
  API_SURE_BUY,
  API_CUSTOMER_DETAILINFO,
  API_SURE_ALLPAYMENT,
} from "@/constants/api";
import "./index.scss";
import { ROLE_CODE } from "@/constants/user";
import { useRef } from "react";
import { useMemo } from "react";

export default withLayout((props) => {
  const { router, person } = props;
  const { name, buildingId, type, id, channelId } = router.params;
  const isFirst = useRef(1);
  const [RenChouData, setRenChouData] = useState({
    name,
    realtyConsultant: "",
    remark: "",
  });

  const [QianYueData, setQianYueData] = useState({
    name,
    realtyConsultant: "",
    remark: "",
    dividendsName: "",
    dividendsPer: "",
    houseInfo: "",
    houseType: "",
    price: "",
    successDate: "",
    totalCommission: "", //佣金总额
    currentCommission: "", //本次结佣
  });

  const [FormData, setFormData] = useState({ ...RenChouData });

  const [ConsultantList, setConsultantList] = useState([]);
  const [HouseTypeList, setHouseTypeList] = useState([]);
  const [CurrnetConsultant, setCurrnetConsultant] = useState({});

  const [SuccessDate, setSuccessDate] = useState(null);
  const [channelCustomerId, setChannelCustomerId] = useState(null);
  const [channelCustomerInfo, setChannelCustomerIdInfo] = useState({});
  const [confirmLoading, setConfirmLoading] = useState(false);
  
  // const [StatusList,setStatusList] = useState([
  //   { name: "认筹", id: 3 },
  //   { name: "签约", id: 4 },
  //   { name: "全款到账", id: 6 },
  //   { name: "结佣", id: 5 },
  // ]);
  const [CurrentStatusId, setCurrentStatusId] = useState(3);

  const [CurrentRoomTypeId, setCurrentRoomTypeId] = useState(null);
  const [isBroker, setIsBroker] = useState(false);

  const StatusList = useMemo(() => {
    if (isBroker) {
      return [
        { name: "认筹", id: 3 },
        { name: "签约", id: 4 },
        { name: "全款到账", id: 6 },
        { name: "结佣", id: 5 },
      ];
    } else {
      return [
        { name: "认筹", id: 3 },
        { name: "签约", id: 4 },

        { name: "结佣", id: 5 },
      ];
    }
  }, [isBroker]);

  useEffect(() => {
    if (buildingId) {
      const params = {
        pageNumber: 1,
        pageSize: 50,
        buildingId,
      };
      getCardList(params).then((res) => {
        const { records } = res;
        setConsultantList(records || []);
      });
    }
  }, [buildingId]);

  const [agentsInfo, setAgentsInfo] = useState({
    name: "",
    channelName: " ",
  });

  useEffect(() => {
    fetch({ url: `${API_CUSTOMER_DETAILINFO}/${id}`, method: "get" }).then(
      (res) => {
        if (res?.channelCustomer?.recommendPersonType === ROLE_CODE.BROKER) {
          setIsBroker(true);
        }
        //获取经纪人信息
        setChannelCustomerIdInfo(res);
        setAgentsInfo({ name: res.name });
        getAgents({ personId: res?.recommendPerson }).then((e) => {
          let ganentsList = e.records;
          if ((ganentsList || []).length) {
            // ganentsList
            setAgentsInfo({
              name: res.name,
              channelName: ganentsList[0].channelName,
            });
          }
        });

        if (CurrentStatusId - 0 === 3) {
          setFormData({
            ...FormData,
            ...res?.customerPreparatory,
            realtyConsultant: res?.realtyConsultant,
          });
        } else {
          setFormData({
            ...FormData,
            ...res?.customerPreparatory,
            totalCommission: res.channelCustomer.totalCommission / 100, //佣金总额
            realtyConsultant: res?.realtyConsultant,
          });
        }

        setChannelCustomerId(res?.channelCustomer?.channelCustomerId);
        setRenChouData({
          ...RenChouData,
          ...res?.customerPreparatory,
          realtyConsultant: res?.realtyConsultant,
        });
        if ((res.customerSignatory || []).length) {
          let customerSignatory = res.customerSignatory[0];
          customerSignatory.dividendsPer =
            customerSignatory.dividendsName.substring(
              customerSignatory.dividendsName.indexOf("|") + 1,
              customerSignatory.dividendsName.indexOf("%")
            );
          customerSignatory.dividendsName =
            customerSignatory.dividendsName.substring(
              0,
              customerSignatory.dividendsName.indexOf("|")
            );
          setQianYueData({
            ...QianYueData,
            ...customerSignatory,
            totalCommission: res.channelCustomer.totalCommission, //佣金总额

            realtyConsultant: res?.realtyConsultant,
          });
          // setQianYueData({ ...QianYueData, ...customerSignatory, realtyConsultant:   (res.customerSignatory || []).length ? res.customerSignatory[0].realtyConsultant : null })

          HouseTypeList.map((item) => {
            if (item.apartmentId === res.customerSignatory[0].houseType) {
              setCurrentRoomTypeId(item.apartmentId);
            }
          });
          setSuccessDate(
            res.customerSignatory[0].successDate?.substring(0, 10)
          );
        }
        // const ConsultantId = CurrentStatusId === 3 ? res.customerPreparatory?.realtyConsultant : (res.customerSignatory || []).length ? res.customerSignatory[0].realtyConsultant : null
        const ConsultantId =
          CurrentStatusId === 3
            ? res?.realtyConsultant
            : (res.customerSignatory || []).length
            ? res.customerSignatory[0].realtyConsultant
            : null;
        // setRenChouData({ realtyConsultant: res?.realtyConsultant })
        console.log(`ConsultantId is`, ConsultantId, id);

        return ConsultantList.map((item) => {
          if (item.id === ConsultantId || `${item.userId}` === ConsultantId) {
            setCurrnetConsultant(item);
          }
        });
      }
    );
  }, [ConsultantList, HouseTypeList, CurrentStatusId]);

  useEffect(() => {
    if (CurrentStatusId - 0 !== 3 && buildingId) {
      fetch({
        url: `${API_BUILDING_HOUSE_TYPE}?buildingId=${buildingId}&pageSize=${500}`,
        method: "get",
      }).then((res) => {
        setHouseTypeList(res.records || []);
      });
    }
  }, [CurrentStatusId, buildingId]);

  // 进入页面带入当前客户的节点状态
  useEffect(() => {
    if (channelCustomerInfo?.status && isFirst.current === 1) {
      isFirst.current++;
      if (channelCustomerInfo?.status == 2) return;

      CutStatus(
        StatusList.filter((x) => x.id === channelCustomerInfo.status)[0]
      )();
    }
  }, [channelCustomerInfo]);

  useEffect(() => {
    console.log("FormData", FormData);
  }, [FormData]);

  const CutStatus = (item) => {
    return () => {
      if (!item.id) return;

      setCurrentStatusId(item.id);
      if (item.id - 0 === 3) {
        setFormData({ ...RenChouData });
      } else if (item.id - 0 === 4) {
        setFormData({ ...QianYueData });
      } else if (item.id - 0 === 5) {
        setFormData({ ...QianYueData });
      } else if (item.id - 0 === 6) {
        setFormData({ ...QianYueData });
      }
    };
  };

  const CutRoomType = (item) => {
    return () => {
      let resData = { ...FormData };
      resData.houseType = item.apartmentId;
      setFormData({ ...resData });
      setCurrentRoomTypeId(item.apartmentId);
    };
  };

  const InputChange = (key, e) => {
    let resData = { ...FormData };
    resData[key] = e.detail.value;
    setFormData({ ...resData });
  };

  const PickerChange = (key, e) => {
    let resData = { ...FormData };
    if (key === "realtyConsultant") {
      resData[key] = ConsultantList[e.detail.value].id;
      resData.realtyConsultantName = ConsultantList[e.detail.value].name;
      setCurrnetConsultant(ConsultantList[e.detail.value]);
    }
    setFormData({ ...resData });
  };

  const CheckForm = () => {
    if (CurrentStatusId === 3) {
      // 认筹
      if (FormData.name === "") {
        Taro.showToast({ title: "姓名不能为空", icon: "none", duration: 2000 });
        return false;
      }
      // if (FormData.realtyConsultant === '') {
      //   Taro.showToast({ title: '请选择内场接待', icon: 'none', duration: 2000 })
      //   return false
      // }
    } else if (CurrentStatusId === 4) {
      // 签约
    }
    return true;
  };

  const ToSubmit = () => {
    if(confirmLoading) return
    let brokerParams = {};

    if (isBroker) {
      (brokerParams.totalCommission = Number(FormData?.totalCommission) * 100),
        (brokerParams.currentCommission =
          Number(FormData?.currentCommission || 0) * 100);
    }


    if (CurrentStatusId === 3) {
     setConfirmLoading(true)
      fetch({
        url: API_SURE_CHIP,
        method: "put",
        payload: {
          customerId: id,
          customerPreparatory: {
            ...FormData,
            channelId:
              channelId === "null" || channelId === null ? "" : channelId,
            channelCustomerId,
          },
        },
      }).then(() => {
   
        Taro.showToast({ title: "修改成功", icon: "none", duration: 2000 });
        
        setTimeout(() => {
          Taro.navigateBack({ delta: 1 });
        }, 2000);
      }).catch(()=>[
        setConfirmLoading(false)
      ]);
    } else if (CurrentStatusId === 4) {
      let params = {};
      for (let key in FormData) {
        if (key !== "dividendsName" && key !== "dividendsPer") {
          params[key] = { ...FormData }[key];
          console.log(
            "🚀 ~ file: index.jsx ~ line 202 ~ ToSubmit ~ FormData",
            FormData
          );
        }
      }
      params.dividendsName = `${FormData.dividendsName||''}|${FormData.dividendsPer||''}%`;

      if (
        Number(params.totalCommission || 0) -
          Number(channelCustomerInfo?.channelCustomer?.settledCommission || 0) /
            100 <
        Number(params.currentCommission || 0)
      ) {
        Taro.showToast({
          title: "本次结佣金额不能大于剩余未结佣金额",
          icon: "none",
          duration: 3000,
        });
        return;
      }
      setConfirmLoading(true)
      fetch({
        url: API_SURE_SIGN,
        method: "put",
        payload: {
          customerId: id,
          customerSignatory: {
            ...params,
            channelId:
              channelId === "null" || channelId === null ? "" : channelId,
            channelCustomerId,
          },
          ...brokerParams,
        },
      }).then(() => {
        Taro.showToast({ title: "修改成功", icon: "none", duration: 2000 });
        setTimeout(() => {
          Taro.navigateBack({ delta: 1 });
        }, 2000);
      }).catch(()=>[
        setConfirmLoading(false)
      ]);
    } else if (CurrentStatusId === 5) {
      let params = {};
      for (let key in FormData) {
        if (key !== "dividendsName" && key !== "dividendsPer") {
          params[key] = { ...FormData }[key];
        }
      }
      params.dividendsName = `${FormData.dividendsName||''}|${FormData.dividendsPer||''}%`;
      if (
        Number(params.totalCommission || 0) -
          Number(channelCustomerInfo?.channelCustomer?.settledCommission || 0) /
            100 <
        Number(params.currentCommission || 0)
      ) {
        Taro.showToast({
          title: "本次结佣金额不能大于剩余未结佣金额",
          icon: "none",
          duration: 3000,
        });
        return;
      }
      setConfirmLoading(true)
      fetch({
        url: API_SURE_BUY,
        method: "put",
        payload: {
          customerId: id,
          customerSignatory: {
            ...params,
            channelId:
              channelId === "null" || channelId === null ? "" : channelId,
            channelCustomerId,
          },

          ...brokerParams,
        },
      }).then(() => {
        Taro.showToast({ title: "修改成功", icon: "none", duration: 2000 });
        setTimeout(() => {
          Taro.navigateBack({ delta: 1 });
        }, 2000);
      }).catch(()=>[
        setConfirmLoading(false)
      ]);
    } else if (CurrentStatusId === 6) {
      let params = {};
      for (let key in FormData) {
        if (key !== "dividendsName" && key !== "dividendsPer") {
          params[key] = { ...FormData }[key];
          console.log(
            "🚀 ~ file: index.jsx ~ line 202 ~ ToSubmit ~ FormData",
            FormData
          );
        }
      }
      params.dividendsName = `${FormData.dividendsName||''}|${FormData.dividendsPer||''}%`;
      if (
        Number(params.totalCommission || 0) -
          Number(channelCustomerInfo?.channelCustomer?.settledCommission || 0) /
            100 <
        Number(params.currentCommission || 0)
      ) {
        Taro.showToast({
          title: "本次结佣金额不能大于剩余未结佣金额",
          icon: "none",
          duration: 3000,
        });
        return;
      }
      setConfirmLoading(true)
      fetch({
        url: API_SURE_ALLPAYMENT,
        method: "put",
        payload: {
          customerId: id,
          customerSignatory: {
            ...params,
            channelId:
              channelId === "null" || channelId === null ? "" : channelId,
            channelCustomerId,
          },
          ...brokerParams,
        },
      }).then(() => {
        Taro.showToast({ title: "修改成功", icon: "none", duration: 2000 });
        setTimeout(() => {
          Taro.navigateBack({ delta: 1 });
        }, 2000);
      }).catch(()=>[
        setConfirmLoading(false)
      ]);
    }
  };

  const SuccessDateChange = (e) => {
    let resData = { ...FormData };
    resData.successDate = new Date(e.detail.value);
    setFormData(resData);
    setSuccessDate(e.detail.value);
  };

  return (
    <view className="Page changeVisit">
      <ScrollView scroll-y>
        <view className="PageContent">
          <text className="required">变更状态</text>
          <view className="FormLine flex-h">
            <view className="flex-item">
              <view className="CheckBoxList">
                {StatusList.map((item, index) => (
                  <view
                    key={`StatusItem-${index}`}
                    onClick={CutStatus(item)}
                    style={{ marginRight: index === 2 ? "0px" : "44rpx" }}
                  >
                    <text>{item.name}</text>
                    {CurrentStatusId === item.id && (
                      <Image
                        mode="widthFix"
                        src={require("@/assets/findHouse-icon1.png")}
                      ></Image>
                    )}
                  </view>
                ))}
              </view>
            </view>
          </view>

          <text className="required">客户姓名</text>
          <view className="FormLine flex-h">
            <view className="flex-item">
              <Input
                placeholder="请输入姓名"
                disabled={CurrentStatusId === 5}
                value={agentsInfo.name}
                onInput={InputChange.bind(this, "name")}
              ></Input>
            </view>
          </view>

          {channelCustomerInfo?.channelCustomer?.recommendPersonType ===
          ROLE_CODE.BROKER ? (
            <>
              <text>报备经纪人</text>
              <view className="FormLine flex-h">
                <view className="flex-item">
                  <Input
                    placeholder="请输入经纪人"
                    disabled
                    value={
                      channelCustomerInfo.channelCustomer?.recommendPersonName
                    }
                  ></Input>
                </view>
              </view>
            </>
          ) : (
            <>
              <text>归属渠道</text>
              <view className="FormLine flex-h">
                <view className="flex-item">
                  <Input
                    placeholder="请输入渠道"
                    disabled
                    value={agentsInfo.channelName}
                  ></Input>
                </view>
              </view>
            </>
          )}

          <text>内场接待</text>
          <view className="FormLine flex-h">
            <view className="flex-item">
              <Picker
                range-key="name"
                range={ConsultantList}
                value={0}
                onChange={PickerChange.bind(this, "realtyConsultant")}
              >
                {CurrnetConsultant.name || "请选择"}
              </Picker>
            </view>
          </view>

          {(CurrentStatusId === 4 ||
            CurrentStatusId === 5 ||
            CurrentStatusId === 6) && (
            <Block>
              <text>业绩分成人|占比/%</text>
              <view className="FormLine flex-h">
                <view className="flex-item">
                  <Input
                    placeholder="请输入业绩分成人"
                    value={FormData.dividendsName}
                    onInput={InputChange.bind(this, "dividendsName")}
                  ></Input>
                </view>
                <view className="flex-item">
                  <Input
                    placeholder="请输入占比%"
                    value={FormData.dividendsPer}
                    type="number"
                    onInput={InputChange.bind(this, "dividendsPer")}
                  ></Input>
                </view>
              </view>
            </Block>
          )}

          {(CurrentStatusId === 4 ||
            CurrentStatusId === 5 ||
            CurrentStatusId === 6) && (
            <Block>
              <text>户型</text>
              <view className="FormLine flex-h">
                <view className="flex-item">
                  <view className="CheckBoxList">
                    {HouseTypeList.map((item, index) => (
                      <view
                        key={`RoomTypeItem-${index}`}
                        onClick={CutRoomType(item)}
                      >
                        <text>{item.apartmentName}</text>
                        {CurrentRoomTypeId === item.apartmentId && (
                          <Image
                            mode="widthFix"
                            src={require("@/assets/findHouse-icon1.png")}
                          ></Image>
                        )}
                      </view>
                    ))}
                  </view>
                </view>
              </view>
            </Block>
          )}

          {(CurrentStatusId === 4 ||
            CurrentStatusId === 5 ||
            CurrentStatusId === 6) && (
            <Block>
              <text>房号</text>
              <view className="FormLine flex-h">
                <view className="flex-item">
                  <Input
                    placeholder="请输入房号"
                    value={FormData.houseInfo}
                    onInput={InputChange.bind(this, "houseInfo")}
                  ></Input>
                </view>
              </view>
            </Block>
          )}

          {(CurrentStatusId === 4 ||
            CurrentStatusId === 5 ||
            CurrentStatusId === 6) && (
            <Block>
              <text>签约日期</text>
              <view className="FormLine flex-h">
                <view className="flex-item">
                  <Picker
                    mode="date"
                    value={FormData.successDate}
                    onChange={SuccessDateChange}
                  >
                    {SuccessDate || "请选择开始日期"}
                  </Picker>
                </view>
                <text className="iconfont icon-jiantoudown"></text>
              </view>
            </Block>
          )}

          {(CurrentStatusId === 4 ||
            CurrentStatusId === 5 ||
            CurrentStatusId === 6) && (
            <Block>
              <text>成交金额</text>
              <view className="FormLine flex-h">
                <view className="flex-item">
                  <Input
                    placeholder="请输入金额"
                    value={FormData.price}
                    onInput={InputChange.bind(this, "price")}
                  ></Input>
                </view>
              </view>
            </Block>
          )}

          {(CurrentStatusId === 4 ||
            CurrentStatusId === 5 ||
            CurrentStatusId === 6) &&
            isBroker && (
              <Block>
                <text>佣金总额</text>
                <view className="FormLine flex-h">
                  <view className="flex-item">
                    <Input
                      type="number"
                      placeholder="请输入金额"
                      disabled={
                        Number(
                          channelCustomerInfo?.channelCustomer
                            ?.settledCommission || 0
                        ) > 0
                      }
                      value={FormData.totalCommission}
                      onInput={InputChange.bind(this, "totalCommission")}
                    ></Input>
                  </view>
                </view>
              </Block>
            )}

          {(CurrentStatusId === 4 ||
            CurrentStatusId === 5 ||
            CurrentStatusId === 6) &&
            isBroker && (
              <Block>
                <text>已结佣金</text>
                <view className="FormLine flex-h">
                  <view className="flex-item">
                    <text>
                      {(channelCustomerInfo?.channelCustomer
                        ?.settledCommission || 0) / 100}
                    </text>
                  </view>
                </view>
              </Block>
            )}

          {(CurrentStatusId === 4 ||
            CurrentStatusId === 5 ||
            CurrentStatusId === 6) &&
            isBroker && (
              <Block>
                <text
                  style={{ display: person.brokerManager ? "block" : "none" }}
                >
                  本次结佣
                </text>
                <view
                  className="FormLine flex-h"
                  style={{ display: person.brokerManager ? "block" : "none" }}
                >
                  <view className="flex-item">
                    <Input
                      type="number"
                      placeholder="请输入金额"
                      value={FormData.currentCommission}
                      onInput={InputChange.bind(this, "currentCommission")}
                    ></Input>
                  </view>
                </view>
              </Block>
            )}

          <text>备注</text>
          <view className="FormLine flex-h">
            <view className="flex-item">
              <Input
                placeholder="补充说明（选填）"
                value={FormData.remark}
                onInput={InputChange.bind(this, "remark")}
              ></Input>
            </view>
          </view>

          <view className="Btn">
            <text onClick={ToSubmit}>提交</text>
          </view>
        </view>
      </ScrollView>
    </view>
  );
});
